/*
 * Copyright (c) 2000 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Evas.h>
#include <Ecore.h>
#include <Ecore_Input.h>

#include "syspopup_core.h"
#include "syspopup.h"
#include "syspopup_api.h"
#include "simple_util.h"
#include "syspopup_wayland.h"

static Eina_Bool __keydown_cb(void *data, int type, void *event)
{
	int id = (int)((intptr_t)data);
	Ecore_Event_Key *ev = event;

	if (ev == NULL)
		return ECORE_CALLBACK_DONE;

	wl_syspopup_process_keypress(id, ev->keyname);

	return ECORE_CALLBACK_PASS_ON;
}

static int __efl_rotate_cb(void *d, void *w, void *s)
{
	return 0;
}

int syspopup_efl_create(const char *popup_name, bundle *b, Evas_Object *parent,
			syspopup_handler *handler, void *user_data)
{
	syspopup *sp;
	syspopup_info_t *info;

	info = _syspopup_info_get(popup_name);
	if (info == NULL) {
		_E("Failed to get syspopup info: %s", popup_name);
		return -1;
	}

	sp = (syspopup *)malloc(sizeof(syspopup));
	if (sp == NULL) {
		_syspopup_info_free(info);
		return -1;
	}

	sp->name = strdup(info->name);
	sp->def_term_fn = handler->def_term_fn;
	sp->def_timeout_fn = handler->def_timeout_fn;
	sp->user_data = user_data;
	sp->win = (void *)parent;
	sp->timeout_id = 0;
	sp->dupped_bundle = bundle_dup(b);
	sp->rotate_cb = __efl_rotate_cb;

	_syspopup_add_new(sp);
	_syspopup_set_term_type(sp, info);
	_syspopup_set_endkey_type(sp, info);

	sp->internal_data = (void *)elm_win_wl_window_get(parent);
	if (wl_syspopup_init(sp, info) < 0) {
		_syspopup_info_free(info);
		_syspopup_del(sp->id);
		return -1;
	}

	_syspopup_reset_timeout(sp, info);
	if (sp->endkey_act != SYSPOPUP_KEYEND_IGNORE) {
		ecore_event_handler_add(ECORE_EVENT_KEY_DOWN, __keydown_cb,
					(const void *)((intptr_t)sp->id));
	}

	_syspopup_info_free(info);

	return sp->id;
}

int syspopup_efl_reset(bundle *b)
{
	return wl_syspopup_reset(b);
}
