/*
 * Copyright (c) 2000 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <bundle.h>
#include <bundle_internal.h>
#include "syspopup_caller.h"

static int __foreach_cb(const char *popup_name, const char *appid,
		void *user_data)
{
	printf("system popup    name [%s]  appid [%s]\n", popup_name, appid);
	return 0;
}

static void usage(void)
{
	printf("[usage] sp_test launch/destroy/foreach popup_name..."
				"(key1,val1,key2,val2,...)\n");
}

int main(int argc, char **argv)
{
	bundle *b;
	int i;
	int ret = 0;

	if (argc < 2) {
		usage();
		return -1;
	}

	if (strcmp(argv[1], "launch") == 0) {
		if ((argc < 3) || (argc % 2 == 0)) {
			usage();
			return -1;
		}

		b = bundle_create();
		for (i = 3; i < argc; i = i + 2)
			bundle_add(b, argv[i], argv[i + 1]);
		ret = syspopup_launch(argv[2], b);
		bundle_free(b);
		if (ret < 0)
			return -1;

	} else if (strcmp(argv[1], "destroy") == 0) {
		ret = syspopup_destroy_all();
		if (ret < 0)
			return -1;
	} else if (strcmp(argv[1], "foreach") == 0) {
		ret = syspopup_foreach_info(__foreach_cb, NULL);
		if (ret < 0)
			return -1;
	} else {
		usage();
	}

	return 0;
}

